@@ -138,6 +138,8 @@ def show(plot, w, h):
         view.w = new_view_w
         view.h = new_view_h
         media.view_set(*view.tuple())
+        if plot.late_vertexors:
+            construct(plot, view, media.width(), media.height())
     reset()
     construct(plot, view, w, h)
     def on_resize(w, h):
@@ -209,7 +211,11 @@ def show(plot, w, h):
                 increment /= 2
             i = view.x // increment * increment + increment
             while i < view.x + view.w:
-                s = '{:.5}'.format(i)
+                if plot.x_axis_transform:
+                    t = plot.x_axis_transform(i)
+                else:
+                    t = i
+                s = '{:.5}'.format(t)
                 if view.x + view.w - i > increment:
                     if i == 0 and plot.epochs.get('x') != None:
                         texter.text(
@@ -231,7 +237,11 @@ def show(plot, w, h):
                 increment /= 2
             i = (view.y + text_h + 2*margin_y) // increment * increment + increment
             while i < view.y + view.h - (text_h + 2*margin_y):
-                s = '{:.5}'.format(i)
+                if plot.y_axis_transform:
+                    t = plot.y_axis_transform(i)
+                else:
+                    t = i
+                s = '{:.5}'.format(t)
                 if i == 0 and plot.epochs.get('y') != None:
                     texter.text(
                         plot.epochs['y']['min'].isoformat('\n'),
@@ -253,5 +263,6 @@ def show(plot, w, h):
         mouse_scroll=on_mouse_scroll,
         key_press=on_key_press,
         draw=on_draw,
+        resize=on_resize,
     )
     media.run()
